@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2009 - DIGITEO - Antoine ELIAS
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -499,9 +499,6 @@ SciErr getVarType(void *_pvCtx, int *_piAddress, int *_piType)
         case types::InternalType::ScilabSparseBool :
             *_piType = sci_boolean_sparse;
             break;
-            //case types::InternalType::RealMatlabSparse :
-            //    *_piType = sci_matlab_sparse;
-            //    break;
         case types::InternalType::ScilabInt8 :
         case types::InternalType::ScilabUInt8 :
         case types::InternalType::ScilabInt16 :
@@ -647,7 +644,6 @@ int isVarMatrixType(void *_pvCtx, int *_piAddress)
             case sci_boolean:
             case sci_sparse:
             case sci_boolean_sparse:
-            case sci_matlab_sparse:
             case sci_ints:
             case sci_handles:
             case sci_strings:
