@@ -116,16 +116,8 @@ void RunVisitorT<T>::visitprivate(const AssignExp  &e)
             if (e.isVerbose() && ConfigVariable::isPrintOutput())
             {
                 std::wstring wstrName = pVar->getSymbol().getName();
-                std::wostringstream ostr;
-                ostr << L" " << wstrName << L"  = " << std::endl;
-                if (ConfigVariable::isPrintCompact() == false)
-                {
-                    ostr << std::endl;
-                }
-                scilabWriteW(ostr.str().c_str());
-                std::wostringstream ostrName;
-                ostrName << wstrName;
-                VariableToString(pIT, ostrName.str().c_str());
+                scilabWriteW(printVarEqualTypeDimsInfo(pIT, wstrName).c_str());
+                VariableToString(pIT, wstrName.c_str());
             }
             CoverageInstance::stopChrono((void*)&e);
             return;
@@ -226,15 +218,9 @@ void RunVisitorT<T>::visitprivate(const AssignExp  &e)
             {
                 if (e.isVerbose() && ConfigVariable::isPrintOutput())
                 {
-                    std::wostringstream ostr;
-                    ostr << L" " << *getStructNameFromExp(pCell) << L"  = " << std::endl;
-                    if (ConfigVariable::isPrintCompact() == false)
-                    {
-                        ostr << std::endl;
-                    }
-                    scilabWriteW(ostr.str().c_str());
-
-                    VariableToString(pOut, ostr.str().c_str());
+                    const std::wstring *pwstName = getStructNameFromExp(pCell);
+                    scilabWriteW(printVarEqualTypeDimsInfo(pOut, *pwstName).c_str());
+                    VariableToString(pOut, pwstName->c_str());
                 }
             }
             else
@@ -401,17 +387,9 @@ void RunVisitorT<T>::visitprivate(const AssignExp  &e)
 
             if (e.isVerbose() && ConfigVariable::isPrintOutput())
             {
-                std::wostringstream ostr;
-                ostr << L" " << *getStructNameFromExp(&pCall->getName()) << L"  = " << std::endl;
-                if (ConfigVariable::isPrintCompact() == false)
-                {
-                    ostr << std::endl;
-                }
-                scilabWriteW(ostr.str().c_str());
-
-                std::wostringstream ostrName;
-                ostrName << *getStructNameFromExp(&pCall->getName());
-                VariableToString(pOut, ostrName.str().c_str());
+                const std::wstring *pwstName = getStructNameFromExp(&pCall->getName());
+                scilabWriteW(printVarEqualTypeDimsInfo(pOut, *pwstName).c_str());
+                VariableToString(pOut, pwstName->c_str());
             }
 
             clearResult();
@@ -555,20 +533,11 @@ void RunVisitorT<T>::visitprivate(const AssignExp  &e)
 
             if (e.isVerbose() && ConfigVariable::isPrintOutput())
             {
-                const std::wstring *pstName = getStructNameFromExp(pField);
+                const std::wstring *pwstName = getStructNameFromExp(pField);
 
-                types::InternalType* pPrint = ctx->get(symbol::Symbol(*pstName));
-                std::wostringstream ostr;
-                ostr << L" " << *pstName << L"  = " << std::endl;
-                if (ConfigVariable::isPrintCompact() == false)
-                {
-                    ostr << std::endl;
-                }
-                scilabWriteW(ostr.str().c_str());
-
-                std::wostringstream ostrName;
-                ostrName << *pstName;
-                VariableToString(pPrint, ostrName.str().c_str());
+                types::InternalType* pPrint = ctx->get(symbol::Symbol(*pwstName));
+                scilabWriteW(printVarEqualTypeDimsInfo(pPrint, *pwstName).c_str());
+                VariableToString(pPrint, pwstName->c_str());
             }
 
             clearResult();
