@@ -90,12 +90,18 @@ extern "C"
 #endif
 
 #include "InitializeTclTk.h"
+#include "TerminateTclTk.h"
 #include "dynamic_link.h"
 
     /* Defined without include to avoid useless header dependency */
     extern BOOL isItTheDisabledLib(void);
 }
 
+__threadId threadIdConsole;
+__threadKey threadKeyConsole;
+__threadId threadIdCommand;
+__threadKey threadKeyCommand;
+
 static void Add_i(void);
 static void Add_pi(void);
 static void Add_eps(void);
@@ -422,6 +428,9 @@ int StartScilabEngine(ScilabEngineInfo* _pSEI)
         if (parser.getExitStatus() == Parser::Failed)
         {
             scilabWriteW(parser.getErrorMessage());
+            // set lasterror to return an error number at scilab exit when -quit is used
+            ConfigVariable::setLastErrorNumber(999);
+            ConfigVariable::setLastErrorMessage(parser.getErrorMessage());
         }
         else if (parser.getControlStatus() !=  Parser::AllControlClosed)
         {
@@ -570,6 +579,7 @@ void StopScilabEngine(ScilabEngineInfo* _pSEI)
     {
         TerminateGraphics();
         TerminateJVM();
+        TerminateTclTk();
     }
 
     // reset struct to prevent the use of deleted objects
@@ -628,6 +638,11 @@ void StopScilabEngine(ScilabEngineInfo* _pSEI)
 
     ConfigVariable::clearLastError();
     ConfigVariable::setEndProcessing(false);
+
+    // wait for the "command" thread end before leaving (and free _pSEI)
+    // the "console" thread may be waiting for a command, so don't wait for it to die
+    // ie: exit in a callback will not release the console
+    __WaitThreadDie(threadIdCommand);
 }
 
 static void processCommand(ScilabEngineInfo* _pSEI)
@@ -716,7 +731,7 @@ void* scilabReadAndExecCommand(void* param)
         processCommand(_pSEI);
         FREE(command);
     }
-    while (ConfigVariable::getForceQuit() == false);
+    while (ConfigVariable::getForceQuit() == false || isEmptyCommandQueue() == false);
 
     return NULL;
 }
@@ -923,11 +938,6 @@ static int interactiveMain(ScilabEngineInfo* _pSEI)
         return 1;
     }
 
-    __threadId threadIdConsole;
-    __threadKey threadKeyConsole;
-    __threadId threadIdCommand;
-    __threadKey threadKeyCommand;
-
     if (_pSEI->iStartConsoleThread)
     {
         // thread to manage console command
@@ -947,6 +957,7 @@ static int interactiveMain(ScilabEngineInfo* _pSEI)
 #endif // DEBUG_THREAD
 
     int iRet = 0;
+    bool bQuit = false;
     do
     {
         // wait for available runner
@@ -967,9 +978,14 @@ static int interactiveMain(ScilabEngineInfo* _pSEI)
             iRet = 1;
         }
 
+        // Check if the queue is empty before unlocking the "command thread".
+        // Sometimes, the "command thread" can unqueue commands between the call of 'SendAwakeRunnerSignal' and the 'while'.
+        // That makes this thread leaving before executing the last runner.
+        bQuit = ConfigVariable::getForceQuit() == false || isEmptyCommandQueue() == false;
+
         ThreadManagement::SendAwakeRunnerSignal();
     }
-    while (ConfigVariable::getForceQuit() == false);
+    while (bQuit);
 
     return iRet;
 }
