@@ -1,5 +1,5 @@
 /*
- *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ *  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2011-2011 - DIGITEO - Bruno JOFRET
  *  Copyright (C) 2014-2015 - Scilab Enterprises - Cedric Delamarre
  *
@@ -26,6 +26,7 @@ extern "C"
 #include "FileBrowserChDir.h"
 #include "scicurdir.h"
 #include "Scierror.h"
+#include "Sciwarning.h"
 #include "InitializeJVM.h"
 }
 
@@ -89,6 +90,8 @@ int StaticRunner::launch()
         ConfigVariable::setPromptMode(-1);
     }
 
+    int iPauseLvl = ConfigVariable::getPauseLevel();
+
     try
     {
         int level = ConfigVariable::getRecursionLevel();
@@ -152,6 +155,8 @@ int StaticRunner::launch()
         if (ConfigVariable::getPauseLevel())
         {
             ConfigVariable::DecreasePauseLevel();
+            // Release the console to display the prompt after aborting a callback execution
+            sendExecDoneSignal();
             // set back the runner wich have been overwritten in StaticRunner::getRunner
             m_CurrentRunner.store(pRunSave);
             throw ia;
@@ -201,8 +206,15 @@ int StaticRunner::launch()
     // reset error state when new prompt occurs
     ConfigVariable::resetError();
 
-    // send the good signal about the end of execution
-    sendExecDoneSignal();
+    // resume will make the execution continue
+    // even if resume is a console command, it must not release the prompt
+    // because the prompt will be released at the end of the original console command
+    // but it must be released if the original command is a callback.
+    if(iPauseLvl == ConfigVariable::getPauseLevel() || (pRunSave && pRunSave->getCommandOrigin() != CONSOLE))
+    {
+        // send the good signal about the end of execution
+        sendExecDoneSignal();
+    }
 
     // send information about execution done to debuggers
     manager->sendExecutionReleased();
