@@ -24,12 +24,14 @@ import java.awt.GraphicsEnvironment;
 import java.awt.Toolkit;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Set;
 
 import javax.swing.JPopupMenu;
 import javax.swing.SwingUtilities;
 
 import org.flexdock.docking.DockingConstants;
 import org.flexdock.docking.DockingManager;
+import org.scilab.modules.action_binding.highlevel.ScilabInterpreterManagement;
 import org.scilab.modules.commons.OS;
 import org.scilab.modules.commons.ScilabCommons;
 import org.scilab.modules.commons.ScilabCommonsUtils;
@@ -260,6 +262,7 @@ public class Scilab {
      */
     public static boolean canClose() {
         final Object lock = new Object();
+        finish = false;
 
         SwingUtilities.invokeLater(new Runnable() {
             @Override
@@ -284,7 +287,6 @@ public class Scilab {
         } catch (InterruptedException e) {
             System.err.println(e);
         }
-        finish = false;
 
         return success;
     }
@@ -294,6 +296,7 @@ public class Scilab {
      */
     public static void forceClose() {
         final Object lock = new Object();
+        finish = false;
 
         SwingUtilities.invokeLater(new Runnable() {
             @Override
@@ -302,6 +305,8 @@ public class Scilab {
                 ClosingOperationsManager.forceClosingOperationOnRoot();
                 exitCalled = false;
 
+                SwingScilabWindow.forceClose();
+
                 finish = true;
                 synchronized (lock) {
                     lock.notify();
@@ -319,6 +324,23 @@ public class Scilab {
             System.err.println(e);
         }
         finish = false;
+
+        ScilabInterpreterManagement.forceClose();
+
+        /* This can be used to debug remaining Threads
+        Thread current = Thread.currentThread();
+        Set<Thread> threadSet = Thread.getAllStackTraces().keySet();
+        for (var t : threadSet)
+        {
+            if (t != current && !t.isDaemon())
+            {
+                System.err.println("interrupting " + t.toString());
+                for (var e : t.getStackTrace())
+                    System.err.println("    " + e.toString());
+                t.stop();
+            }
+        }
+        */
     }
 
     /**
