@@ -1,5 +1,5 @@
 /*
- *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ *  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2015 - Scilab Enterprises - Calixte DENIZET
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -20,13 +20,14 @@
 #include <libxml/xmlreader.h>
 #include <libxml/xpath.h>
 
+#include <algorithm>
+
 #include "CovHTMLCodePrinter.hxx"
 #include "CoverModule.hxx"
-#include "allexp.hxx"
-#include "alltypes.hxx"
-#include "allvar.hxx"
 #include "cover_tools.hxx"
 #include "coverage_instance.hxx"
+#include "parser.hxx"
+#include "macrofile.hxx"
 
 extern "C"
 {
@@ -37,6 +38,7 @@ extern "C"
 #include "freeArrayOfString.h"
 #include "isdir.h"
 #include "os_string.h"
+#include "sciprint.h"
 #include "sci_malloc.h"
 }
 
@@ -46,6 +48,18 @@ extern "C"
 #define DEFAULT_FILESPEC L"*"
 #endif
 
+namespace
+{
+std::wstring expandPathVariable(const std::wstring& p )
+{
+
+    wchar_t* localPath = expandPathVariableW((wchar_t*)p.c_str());
+    std::wstring l(localPath);
+    FREE(localPath);
+    return l;
+}
+}
+
 namespace coverage
 {
 
@@ -85,55 +99,72 @@ CoverModule::~CoverModule()
 
 const std::vector<std::pair<std::wstring, std::wstring>> CoverModule::getModule(const std::vector<std::wstring>& moduleNames)
 {
-    const std::wstring _path = std::wstring(L"SCI") + DIR_SEPARATORW + L"modules" + DIR_SEPARATORW;
-    wchar_t* __path = expandPathVariableW((wchar_t*)_path.c_str());
-    const std::wstring path(__path);
-    FREE(__path);
-
-    if (moduleNames.size() == 1 && moduleNames.back() == L"all")
+    if (moduleNames.size() == 0)
     {
-        int size = -1;
-        wchar_t** files = findfilesW(path.c_str(), DEFAULT_FILESPEC, &size, FALSE);
-        if (size > 0 && files)
-        {
-            std::vector<std::pair<std::wstring, std::wstring>> paths;
-            for (int i = 0; i < size; ++i)
-            {
-                const std::wstring modulePath = path + files[i];
-                if (isdirW(modulePath.c_str()))
-                {
-                    paths.emplace_back(modulePath, files[i]);
-                }
-            }
-            freeArrayOfWideString(files, size);
-            return paths;
-        }
-
+        // nothing to do, return empty
         return {};
     }
-    else
+
+    if (std::all_of(moduleNames.begin(), moduleNames.end(),
+                    [](const std::wstring & p)
+{
+    return isdirW(expandPathVariable(p).c_str()) == TRUE;
+    }))
     {
+        // all the provided modulesNames are directories, name them and remove "\macros"
         std::vector<std::pair<std::wstring, std::wstring>> paths;
+
+        // remove any potential "\macros" suffix
         for (const auto& name : moduleNames)
         {
-            paths.emplace_back(path + name, name);
+            const std::wstring remove(std::wstring(DIR_SEPARATORW) + std::wstring(L"macros"));
+            std::wstring localName;
+            size_t n = name.rfind(remove);
+            if (n > 0)
+            {
+                localName = name.substr(0, n) + name.substr(n + remove.length());
+            }
+            else
+            {
+                localName = name;
+            }
+            n = localName.rfind(DIR_SEPARATORW);
+            if (n > 0)
+            {
+                localName = localName.substr(n + 1, localName.length() - n);
+            }
+
+            paths.emplace_back(expandPathVariable(name), std::move(localName));
         }
         return paths;
     }
+
+    // Look for the names as Scilab-related libraries
+    const std::wstring _path = std::wstring(L"SCI") + DIR_SEPARATORW + L"modules" + DIR_SEPARATORW;
+    const std::wstring path(expandPathVariable(_path));
+
+    // a list of Scilab libraries
+    std::vector<std::pair<std::wstring, std::wstring>> paths;
+    for (const auto& name : moduleNames)
+    {
+        paths.emplace_back(path + name, name);
+    }
+    return paths;
 }
 
 void CoverModule::getMacros(const std::vector<std::pair<std::wstring, std::wstring>>& paths_mods)
 {
     for (const auto& p : paths_mods)
     {
-        std::wstring _path = p.first + DIR_SEPARATORW + L"macros";
-        getMacrosFromDir(_path, p.second);
+        getMacrosFromDir(p.first, p.second);
     }
 }
 
 void CoverModule::getMacrosFromDir(const std::wstring& path, const std::wstring& module)
 {
-    std::wstring _path = path + DIR_SEPARATORW + L"lib";
+    const std::wstring resolvedPath(expandPathVariable(path));
+
+    std::wstring _path = resolvedPath + DIR_SEPARATORW + L"lib";
     getMacros(_path, module);
 
     int size = -1;
@@ -157,9 +188,7 @@ void CoverModule::getMacrosFromDir(const std::wstring& path, const std::wstring&
 void CoverModule::getMacros(const std::wstring& path, const std::wstring& module)
 {
     std::unordered_set<std::wstring> _macros;
-    wchar_t* pwstPathLib = expandPathVariableW((wchar_t*)path.c_str());
-    std::wstring libPath(pwstPathLib);
-    FREE(pwstPathLib);
+    std::wstring libPath(expandPathVariable(path));
 
     char* libFile = wide_string_to_UTF8(libPath.c_str());
 
@@ -312,7 +341,9 @@ std::vector<Counter>::const_iterator CoverModule::lower_bound(const std::vector<
     for (auto it = first; it < last; it++)
     {
         if (it->getMacro() == value)
+        {
             return it;
+        }
     }
 
     return last;
@@ -324,7 +355,9 @@ std::vector<Counter>::const_iterator CoverModule::upper_bound(const std::vector<
     for (auto it = lower_bound(first, last, value); it < last; it++)
     {
         if (it->getMacro() != value)
+        {
             return it;
+        }
     }
 
     return last;
@@ -739,8 +772,8 @@ const std::wstring CoverModule::getName(const std::wstring& path)
 
 void CoverModule::writeMacroHTMLReport(types::Macro* macro, std::map<MacroLoc, CoverResult>& results, const std::wstring& outputDir)
 {
-    std::list<symbol::Variable*>* in = macro->getInputs();
-    std::list<symbol::Variable*>* out = macro->getOutputs();
+    std::vector<symbol::Variable*>* in = macro->getInputs();
+    std::vector<symbol::Variable*>* out = macro->getOutputs();
     ast::SeqExp& body = *macro->getBody()->clone();
 
     ast::exps_t& _in = *new ast::exps_t();
