@@ -1,5 +1,5 @@
 /*
- *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ *  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2015 - Scilab Enterprises - Calixte DENIZET
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -16,9 +16,6 @@
 #include "CoverModule.hxx"
 #include "CoverResult.hxx"
 #include "cover_tools.hxx"
-#include "allexp.hxx"
-#include "allvar.hxx"
-#include "alltypes.hxx"
 #include "printvisitor.hxx"
 
 extern "C"
