@@ -1,5 +1,5 @@
 /*
-* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+* Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2011 - DIGITEO - Cedric DELAMARRE
 *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -122,12 +122,6 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
         {
             meth = 3;
         }
-        else if (wcscmp(wcsType, L"roots") == 0)
-        {
-            sciprint(_("%s: Feature %s is obsolete.\n"), _("Warning"), "roots");
-            sciprint(_("%s: Please use %s instead.\n"), _("Warning"), "root");
-            meth = 3;
-        }
         else if (wcscmp(wcsType, L"discrete") == 0)
         {
             meth = 4;
@@ -566,7 +560,7 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
     if (bFuncF == false)
     {
         int val = (meth == 3) ? 3 : 1;
-        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), "ode", in.size() + val);
+        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), "ode", (int) in.size() + val);
         DifferentialEquation::removeDifferentialEquationFunctions();
         FREE(pdYData);
         FREE(YSize);
@@ -574,7 +568,7 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
     }
     if (pDblNg == NULL && meth == 3)
     {
-        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), "ode", in.size() + 2);
+        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), "ode", (int) in.size() + 2);
         DifferentialEquation::removeDifferentialEquationFunctions();
         FREE(pdYData);
         FREE(YSize);
@@ -582,7 +576,7 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
     }
     if (bFuncG == false && meth == 3)
     {
-        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), "ode", in.size() + 1);
+        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), "ode", (int) in.size() + 1);
         DifferentialEquation::removeDifferentialEquationFunctions();
         FREE(pdYData);
         FREE(YSize);
