@@ -31,10 +31,16 @@ void clean(double* pdblReal, double* pdblImg, int iSize, double dEpsA, double dE
             double d = dabss(pdblReal[i])+dabss(pdblImg[i]);
             if (std::isfinite(d))
             {
-               dNorm += d;
+               dNorm = Max(dNorm, d);
             }
         }
 
+        if(dNorm == 0)
+        {
+            // only no finite or zero values
+            return;
+        }
+
         double dEps = Max(dEpsA, dEpsR * dNorm);
         for (int i = 0 ; i < iSize ; i++)
         {
@@ -58,9 +64,16 @@ void clean(double* pdblReal, double* pdblImg, int iSize, double dEpsA, double dE
             double d = dabss(pdblReal[i]);
             if (std::isfinite(d))
             {
-               dNorm += d;
+               dNorm = Max(dNorm, d);
             }
         }
+
+        if(dNorm == 0)
+        {
+            // only no finite or zero values
+            return;
+        }
+
         double dEps = Max(dEpsA, dEpsR * dNorm);
         for (int i = 0 ; i < iSize ; i++)
         {
