@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2006 - INRIA - Allan CORNET
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -27,7 +27,6 @@ STACK_GATEWAY_PROTOTYPE(sci_movefile);
 STACK_GATEWAY_PROTOTYPE(sci_fscanfMat);
 STACK_GATEWAY_PROTOTYPE(sci_fprintfMat);
 STACK_GATEWAY_PROTOTYPE(sci_getURL);
-STACK_GATEWAY_PROTOTYPE(sci_splitURL);
 STACK_GATEWAY_PROTOTYPE(sci_tempname);
 /*--------------------------------------------------------------------------*/
 #endif /* __GW_FILEIO_H__ */
