@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2007 - INRIA - Allan CORNET
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -40,11 +40,9 @@ BOOL InitializeGUI()
         {
             org_scilab_modules_gui_bridge::CallScilabBridge::registerSwingView(getScilabJavaVM());
         }
-
-        return TRUE;
     }
 
-    return FALSE;
+    return TRUE;
 }
 
 /*--------------------------------------------------------------------------*/
