@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2007 - INRIA - Vincent Couvert
  * Copyright (C) 2007 - INRIA - Marouane BEN JELLOUL
  *
@@ -106,7 +106,7 @@ public class SwingScilabFrame extends JPanel implements SwingViewObject, Widget
 
     // BJ: This EditorEventListener leads to a huge leak mem openning many Axes withih Frames.
     // DO NOT ACTIVATE THIS until EditorEventListener can manage Axes within Frames (Only Figure is working now)
-    //private EditorEventListener editorEventHandler = null;
+    private EditorEventListener editorEventHandler = null;
 
     private ScilabEventListener eventHandler;
     private boolean eventEnabled = false;
@@ -224,13 +224,13 @@ public class SwingScilabFrame extends JPanel implements SwingViewObject, Widget
 
         if (member instanceof SwingScilabAxes) {
             if (canvas == null) {
-                //editorEventHandler = new EditorEventListener(getId());
+                editorEventHandler = new EditorEventListener(getId());
                 AxesContainer frame = (AxesContainer) GraphicModel.getModel().getObjectFromId(getId());
                 canvas = new SwingScilabCanvas(frame);
-                //canvas.addEventHandlerKeyListener(editorEventHandler);
-                //canvas.addEventHandlerMouseListener(editorEventHandler);
-                //canvas.addEventHandlerMouseMotionListener(editorEventHandler);
-                //editorEventHandler.setEnable(true);
+                canvas.addEventHandlerKeyListener(editorEventHandler);
+                canvas.addEventHandlerMouseListener(editorEventHandler);
+                canvas.addEventHandlerMouseMotionListener(editorEventHandler);
+                editorEventHandler.setEnable(true);
 
                 setLayout(new GridLayout(1, 1));
                 hasLayout = true;
@@ -526,9 +526,9 @@ public class SwingScilabFrame extends JPanel implements SwingViewObject, Widget
      */
     public void destroy() {
         this.setVisible(false);
-        //if (editorEventHandler != null) {
-        //    editorEventHandler.onExit();
-        //}
+        if (editorEventHandler != null) {
+            editorEventHandler.onExit();
+        }
     }
 
     /**
@@ -868,7 +868,7 @@ public class SwingScilabFrame extends JPanel implements SwingViewObject, Widget
         disableEventHandler();
         eventHandler = new ScilabEventListener(funName, getId());
         if (eventEnabled) {
-            //editorEventHandler.setEnable(false);
+            editorEventHandler.setEnable(false);
             enableEventHandler();
         }
     }
@@ -883,11 +883,11 @@ public class SwingScilabFrame extends JPanel implements SwingViewObject, Widget
         }
 
         if (status) {
-            //editorEventHandler.setEnable(false);
+            editorEventHandler.setEnable(false);
             enableEventHandler();
             eventEnabled = true;
         } else {
-            //editorEventHandler.setEnable(true);
+            editorEventHandler.setEnable(true);
             disableEventHandler();
             eventEnabled = false;
         }
