@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2012 - Scilab Enterprises - Calixte DENIZET
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -16,15 +16,9 @@
 #ifndef __HDF5OBJECTS_H__
 #define __HDF5OBJECTS_H__
 
-#define H5_NO_DEPRECATED_SYMBOLS
-#undef H5_USE_16_API
-
-#define H5Eset_auto_vers 2
 #include <hdf5.h>
 #include <hdf5_hl.h>
 
-#undef H5_NO_DEPRECATED_SYMBOLS
-
 //#define __HDF5OBJECTS_DEBUG__
 //#define __HDF5ERROR_PRINT__
 
