@@ -1,5 +1,5 @@
 /*
-*  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+*  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
 *  Copyright (C) 2012 - Scilab Enterprises - Antoine ELIAS
 *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -13,8 +13,6 @@
 *
 */
 
-#define H5_NO_DEPRECATED_SYMBOLS
-
 #ifndef _MSC_VER
 #include <sys/time.h>
 #else
@@ -47,7 +45,7 @@ static herr_t op_func_v1(hid_t loc_id, const char *name, const H5L_info_t *info,
 {
     H5O_info_t oinfo;
     herr_t status = 0;
-    int *pDataSetId = (int*)operator_data;
+    hid_t* pDataSetId = (hid_t*)operator_data;
     hid_t obj = H5Oopen(loc_id, name, H5P_DEFAULT);
     if (obj < 0)
     {
