@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2010 - Calixte DENIZET
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -19,6 +19,7 @@ import java.io.File;
 import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.net.MalformedURLException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -42,6 +43,7 @@ import org.xml.sax.Attributes;
 import org.xml.sax.InputSource;
 import org.xml.sax.Locator;
 import org.xml.sax.SAXException;
+import org.xml.sax.SAXParseException;
 import org.xml.sax.helpers.DefaultHandler;
 
 /**
@@ -52,7 +54,7 @@ public abstract class DocbookTagConverter extends DefaultHandler implements Conv
 
     private static final String DOCBOOKURI = "http://docbook.org/ns/docbook";
     private static final Class<?>[] argsType = new Class[] {Map.class, String.class};
-    protected static final String SCI = ScilabConstants.SCI.getPath();
+    protected static final String SCI = ScilabConstants.SCI.toURI().getPath();
 
     private Map<String, Method> mapMeth = new HashMap<String, Method>();
     private Map<String, ExternalXMLHandler> externalHandlers = new HashMap<String, ExternalXMLHandler>();
@@ -433,6 +435,7 @@ public abstract class DocbookTagConverter extends DefaultHandler implements Conv
                 stack.pop();
                 stack.peek().getStringBuilder().append(str);
             }
+
         }
 
         if (converters != null) {
@@ -546,7 +549,7 @@ public abstract class DocbookTagConverter extends DefaultHandler implements Conv
     private String makeErrorMessage(Exception e) {
         String sId = "";
         if (currentFileName != null) {
-            sId = "SystemID:" + currentFileName;
+            sId = "SystemID: " + currentFileName;
         }
 
         String file;
@@ -557,9 +560,9 @@ public abstract class DocbookTagConverter extends DefaultHandler implements Conv
             file = null;
         }
         if (locator != null) {
-            return "\nCannot parse " + file + ":\n" + e.getMessage() + "\n" + sId + " at line " + locator.getLineNumber();
+            return "\nCannot parse " + file + ":\n" + sId + String.format(":%d:%d", locator.getLineNumber(), locator.getColumnNumber()) + "\n\t" + e.getMessage();
         } else {
-            return "\nCannot parse " + file + ":\n" + e.getMessage() + "\n" + sId;
+            return "\nCannot parse " + file + ":\n" + sId + "\n\t" + e.getMessage();
         }
     }
 
@@ -590,6 +593,14 @@ public abstract class DocbookTagConverter extends DefaultHandler implements Conv
         return buf;
     }
 
+    /**
+     * Handle an exception without throwing it
+     * @param e the exception to handle
+     */
+    public void error(SAXParseException e) {
+        exceptionOccurred(e);
+    }
+
     /*
      * All Handled tag method definition, these methods are the implementation of "Docbook 5.0 - subset Scilab"
      */
