@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2012 - Pedro Arthur dos S. Souza
  * Copyright (C) 2012 - Caio Lucas dos S. Souza
  * Copyright (C) 2014 - Scilab Enterprises - Calixte DENIZET
@@ -55,42 +55,45 @@ public class EntityPicker {
      */
     public Integer pick(Integer figureUid, Integer posX, Integer posY) {
         Integer[] position = {posX, posY};
-        Integer axes = AxesHandler.clickedAxes(figureUid, position);
-        if (axes == null) {
+        Integer[] matchingAxes = AxesHandler.clickedAxes(figureUid, position);
+        if (matchingAxes == null) {
             return null;
         }
 
         double[] pos = {posX.doubleValue(), posY.doubleValue(), 1.0};
-        double[] c2d = CallRenderer.get2dViewFromPixelCoordinates(axes, pos);
 
-        /* Checks if the click is outside canvas drawable area*/
-        if (AxesHandler.isZoomBoxEnabled(axes) && !AxesHandler.isInZoomBoxBounds(axes, c2d[0], c2d[1])) {
-            return null;
-        }
+        for (Integer axes : matchingAxes) {
+            double[] c2d = CallRenderer.get2dViewFromPixelCoordinates(axes, pos);
 
-        Integer polylines[] = (new ObjectSearcher()).search(axes, GraphicObjectProperties.__GO_POLYLINE__);
-        if (polylines != null) {
-            for (int i = 0; i < polylines.length; ++i) {
-                if (CommonHandler.isVisible(polylines[i])) {
-                    if (CommonHandler.isLineEnabled(polylines[i])) {
-                        if (isOverLine(axes, polylines[i], posX, posY) != -1) {
-                            return polylines[i];
+            /* Checks if the click is outside canvas drawable area*/
+            if (AxesHandler.isZoomBoxEnabled(axes) && !AxesHandler.isInZoomBoxBounds(axes, c2d[0], c2d[1])) {
+                continue;
+            }
+
+            Integer polylines[] = (new ObjectSearcher()).search(axes, GraphicObjectProperties.__GO_POLYLINE__);
+            if (polylines != null) {
+                for (int i = 0; i < polylines.length; ++i) {
+                    if (CommonHandler.isVisible(polylines[i])) {
+                        if (CommonHandler.isLineEnabled(polylines[i])) {
+                            if (isOverLine(axes, polylines[i], posX, posY) != -1) {
+                                return polylines[i];
+                            }
                         }
-                    }
 
-                    if (CommonHandler.isMarkEnabled(polylines[i])) {
-                        if (isOverMark(axes, polylines[i], posX, posY) != -1) {
-                            return polylines[i];
+                        if (CommonHandler.isMarkEnabled(polylines[i])) {
+                            if (isOverMark(axes, polylines[i], posX, posY) != -1) {
+                                return polylines[i];
+                            }
                         }
-                    }
 
-                    if (!CommonHandler.isLineEnabled(polylines[i])) {
-                        if (isOverDot(axes, polylines[i], posX, posY) != -1) {
-                            return polylines[i];
+                        if (!CommonHandler.isLineEnabled(polylines[i])) {
+                            if (isOverDot(axes, polylines[i], posX, posY) != -1) {
+                                return polylines[i];
+                            }
                         }
                     }
                 }
-            }
+            }            
         }
 
         return null;
@@ -115,7 +118,7 @@ public class EntityPicker {
     }
 
     public static double[] getSegment(Integer figureUid, Integer uid, int index, int x, int y) {
-        final Integer axes = AxesHandler.clickedAxes(figureUid, new Integer[] {x, y});
+        final Integer axes = (new ObjectSearcher()).searchParent(uid, GraphicObjectProperties.__GO_AXES__);
         final double[][] pixs = EntityPicker.getPixelsData(axes, uid);
         final double[] p1 = pixs[index];
         final double[] p2 = pixs[index + 1];
@@ -414,25 +417,29 @@ public class EntityPicker {
         PickedPoint point = new PickedPoint(-1, false);
         Integer[] position = new Integer[] {px, py};
         Integer figUid = (new ObjectSearcher()).searchParent(uid, GraphicObjectProperties.__GO_FIGURE__);
-        Integer axes = AxesHandler.clickedAxes(figUid, position);
-        if (axes == null) {
+        Integer[] matchingAxes = AxesHandler.clickedAxes(figUid, position);
+        if (matchingAxes == null) {
             return point;
         }
 
-        if (CommonHandler.isMarkEnabled(uid)) {
-            point.point = isOverMark(axes, uid, px, py);
+        for (Integer axes : matchingAxes) {
+            if (CommonHandler.isMarkEnabled(uid)) {
+                point.point = isOverMark(axes, uid, px, py);
+                if (point.point != -1) {
+                    return point;
+                }
+            }
+
+            if (CommonHandler.isLineEnabled(uid)) {
+                point.point = isOverLine(axes, uid, px, py);
+                point.isSegment = true;
+            } else {
+                point.point = isOverDot(axes, uid, px, py);
+            }
             if (point.point != -1) {
                 return point;
             }
         }
-
-        if (CommonHandler.isLineEnabled(uid)) {
-            point.point = isOverLine(axes, uid, px, py);
-            point.isSegment = true;
-        } else {
-            point.point = isOverDot(axes, uid, px, py);
-        }
-
         return point;
     }
 
@@ -474,15 +481,24 @@ public class EntityPicker {
      * @return The LegendInfo if picked a legend null otherwise.
      */
     public LegendInfo pickLegend(Integer figure, Integer[] position) {
-        Integer axes = AxesHandler.clickedAxes(figure, position);
-        if (axes == null) {
+        Integer[] matchingAxes = AxesHandler.clickedAxes(figure, position);
+        if (matchingAxes == null) {
             return null;
         }
-        Integer legend = LegendHandler.searchLegend(axes);
+        
+        Integer legend = null;
+        Integer axes = null;
+        for (Integer searchAxes : matchingAxes) {
+            legend = LegendHandler.searchLegend(searchAxes);
+            if (legend != null) {
+                axes = searchAxes;
+                break;
+            }
+        }
         if (legend == null) {
             return null;
         }
-
+        
         Integer[] links;
         Integer[] axesSize = {0, 0};
         Double delta;
@@ -521,8 +537,8 @@ public class EntityPicker {
      */
     public static AxesHandler.axisTo pickLabel(Integer figure, Integer[] pos) {
 
-        Integer axes = AxesHandler.clickedAxes(figure, pos);
-        if (axes == null) {
+        Integer matchingAxes[] = AxesHandler.clickedAxes(figure, pos);
+        if (matchingAxes == null) {
             return null;
         }
         Double[] corners;
@@ -530,46 +546,51 @@ public class EntityPicker {
         int rotate = 0;
         double[] point = new double[3];
         double[] coord;
-        Integer[] label = {  (Integer)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_X_AXIS_LABEL__),
-                             (Integer)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_Y_AXIS_LABEL__),
-                             (Integer)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_Z_AXIS_LABEL__),
-                             (Integer)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_TITLE__)
-                          };
 
-        boolean[] logScale = {  (Boolean)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_X_AXIS_LOG_FLAG__),
-                                (Boolean)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_Y_AXIS_LOG_FLAG__)
-                             };
+        for (Integer axes : matchingAxes) {
 
-        for (Integer i = 0; i < 4; i++) {
-            corners = (Double[])GraphicController.getController().getProperty(label[i], GraphicObjectProperties.__GO_CORNERS__);
-            radAngle = (Double)GraphicController.getController().getProperty(label[i], GraphicObjectProperties.__GO_FONT_ANGLE__);
-            rotate = ((int)((radAngle * 2) / Math.PI)) % 2;
-            if (rotate == 1) {
-                corners = rotateCorners(corners);
-            }
-            point[0] = pos[0];
-            point[1] = pos[1];
-            point[2] = 1.0;
-            coord = CallRenderer.get2dViewFromPixelCoordinates(axes, point);
+            Integer[] label = {  (Integer)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_X_AXIS_LABEL__),
+                                 (Integer)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_Y_AXIS_LABEL__),
+                                 (Integer)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_Z_AXIS_LABEL__),
+                                 (Integer)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_TITLE__)
+                              };
 
-            coord[0] = CommonHandler.InverseLogScale(coord[0], logScale[0]);
-            coord[1] = CommonHandler.InverseLogScale(coord[1], logScale[1]);
+            boolean[] logScale = {  (Boolean)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_X_AXIS_LOG_FLAG__),
+                                    (Boolean)GraphicController.getController().getProperty(axes, GraphicObjectProperties.__GO_Y_AXIS_LOG_FLAG__)
+                                 };
 
-            if ((coord[0] >= corners[0] && coord[0] <= corners[6]) || (coord[0] <= corners[0] && coord[0] >= corners[6])) {
-                if ((coord[1] >= corners[1] && coord[1] <= corners[4]) || (coord[1] <= corners[1] && coord[1] >= corners[4])) {
-                    switch (i) {
-                        case 0:
-                            return AxesHandler.axisTo.__X__;
-                        case 1:
-                            return AxesHandler.axisTo.__Y__;
-                        case 2:
-                            return AxesHandler.axisTo.__Z__;
-                        case 3:
-                            return AxesHandler.axisTo.__TITLE__;
+            for (Integer i = 0; i < 4; i++) {
+                corners = (Double[])GraphicController.getController().getProperty(label[i], GraphicObjectProperties.__GO_CORNERS__);
+                radAngle = (Double)GraphicController.getController().getProperty(label[i], GraphicObjectProperties.__GO_FONT_ANGLE__);
+                rotate = ((int)((radAngle * 2) / Math.PI)) % 2;
+                if (rotate == 1) {
+                    corners = rotateCorners(corners);
+                }
+                point[0] = pos[0];
+                point[1] = pos[1];
+                point[2] = 1.0;
+                coord = CallRenderer.get2dViewFromPixelCoordinates(axes, point);
+
+                coord[0] = CommonHandler.InverseLogScale(coord[0], logScale[0]);
+                coord[1] = CommonHandler.InverseLogScale(coord[1], logScale[1]);
+
+                if ((coord[0] >= corners[0] && coord[0] <= corners[6]) || (coord[0] <= corners[0] && coord[0] >= corners[6])) {
+                    if ((coord[1] >= corners[1] && coord[1] <= corners[4]) || (coord[1] <= corners[1] && coord[1] >= corners[4])) {
+                        switch (i) {
+                            case 0:
+                                return AxesHandler.axisTo.__X__;
+                            case 1:
+                                return AxesHandler.axisTo.__Y__;
+                            case 2:
+                                return AxesHandler.axisTo.__Z__;
+                            case 3:
+                                return AxesHandler.axisTo.__TITLE__;
+                        }
                     }
                 }
-            }
+            }            
         }
+
         return null;
     }
 
@@ -605,70 +626,76 @@ public class EntityPicker {
      * @return The SurfaceInfo if picked a surface null otherwise.
      */
     public SurfaceInfo pickSurface(Integer figure, Integer[] mousePos) {
-        Integer uid = AxesHandler.clickedAxes(figure, mousePos);
-        Axes curAxes = (Axes)GraphicController.getController().getObjectFromId(uid);
-        if (curAxes == null) {
-            return null;
-        }
+        Integer[] matchingAxes = AxesHandler.clickedAxes(figure, mousePos);
 
-        double[][] factors = curAxes.getScaleTranslateFactors();
-        //double[] mat = DrawerVisitor.getVisitor(figure).getAxesDrawer().getProjection(uid).getMatrix();
+        for (Integer uid : matchingAxes) {
+            Axes curAxes = (Axes)GraphicController.getController().getObjectFromId(uid);
+            if (curAxes == null) {
+                return null;
+            }
 
-        Vector3d v0 = AxesDrawer.unProject(curAxes, new Vector3d(1.0f * mousePos[0], 1.0f * mousePos[1], 0.0));
-        Vector3d v1 = AxesDrawer.unProject(curAxes, new Vector3d(1.0f * mousePos[0], 1.0f * mousePos[1], 1.0));
-        v0 = new Vector3d((v0.getX() - factors[1][0]) / factors[0][0], (v0.getY() - factors[1][1]) / factors[0][1], (v0.getZ() - factors[1][2]) / factors[0][2]);
-        v1 = new Vector3d((v1.getX() - factors[1][0]) / factors[0][0], (v1.getY() - factors[1][1]) / factors[0][1], (v1.getZ() - factors[1][2]) / factors[0][2]);
+            double[][] factors = curAxes.getScaleTranslateFactors();
+            //double[] mat = DrawerVisitor.getVisitor(figure).getAxesDrawer().getProjection(uid).getMatrix();
 
-        Vector3d Dir = v0.minus(v1).getNormalized();
-        // ray is the parametric cuve t -> v0 + T * Dir
-        Integer[] types = {GraphicObjectProperties.__GO_PLOT3D__, GraphicObjectProperties.__GO_FAC3D__, GraphicObjectProperties.__GO_GRAYPLOT__};
-        Integer[] objs = (new ObjectSearcher()).searchMultiple(figure, types);
-        double T = Double.NEGATIVE_INFINITY;
-        SurfaceInfo info = new SurfaceInfo();
-        if (objs != null) {
-            for (int i = 0; i < objs.length; ++i) {
-                double curT = SurfaceData.pickSurface(objs[i], v0.getX(), v0.getY(), v0.getZ(), Dir.getX(), Dir.getY(), Dir.getZ());
-                if (curT > T) {
-                    T = curT;
-                    info.surface = objs[i];
+            Vector3d v0 = AxesDrawer.unProject(curAxes, new Vector3d(1.0f * mousePos[0], 1.0f * mousePos[1], 0.0));
+            Vector3d v1 = AxesDrawer.unProject(curAxes, new Vector3d(1.0f * mousePos[0], 1.0f * mousePos[1], 1.0));
+            v0 = new Vector3d((v0.getX() - factors[1][0]) / factors[0][0], (v0.getY() - factors[1][1]) / factors[0][1], (v0.getZ() - factors[1][2]) / factors[0][2]);
+            v1 = new Vector3d((v1.getX() - factors[1][0]) / factors[0][0], (v1.getY() - factors[1][1]) / factors[0][1], (v1.getZ() - factors[1][2]) / factors[0][2]);
+
+            Vector3d Dir = v0.minus(v1).getNormalized();
+            // ray is the parametric cuve t -> v0 + T * Dir
+            Integer[] types = {GraphicObjectProperties.__GO_PLOT3D__, GraphicObjectProperties.__GO_FAC3D__, GraphicObjectProperties.__GO_GRAYPLOT__};
+            Integer[] objs = (new ObjectSearcher()).searchMultiple(figure, types);
+            double T = Double.NEGATIVE_INFINITY;
+            SurfaceInfo info = new SurfaceInfo();
+            if (objs != null) {
+                for (int i = 0; i < objs.length; ++i) {
+                    double curT = SurfaceData.pickSurface(objs[i], v0.getX(), v0.getY(), v0.getZ(), Dir.getX(), Dir.getY(), Dir.getZ());
+                    if (curT > T) {
+                        T = curT;
+                        info.surface = objs[i];
+                    }
                 }
+                if (info.surface != null) {
+                    info.point = new Vector3d(v0.plus(Dir.times(T))); // point = v0 + T * Dir
+                    return info;
+                }
+                // if formerly used normalized Z \in [-1,1] is to be computed:
+                // Z = info.point.getX() * mat[2] + info.point.getY() * mat[6] + info.point.getZ() * mat[10] + mat[14];
             }
-            if (info.surface != null) {
-                info.point = new Vector3d(v0.plus(Dir.times(T))); // point = v0 + T * Dir
-            }
-            // if formerly used normalized Z \in [-1,1] is to be computed:
-            // Z = info.point.getX() * mat[2] + info.point.getY() * mat[6] + info.point.getZ() * mat[10] + mat[14];
         }
-        return info;
+        return null;
     }
 
 
     public Integer pickDatatip(Integer figure, Integer[] pos) {
-        Integer axes = AxesHandler.clickedAxes(figure, pos);
-        if (axes == null) {
+        Integer[] matchingAxes = AxesHandler.clickedAxes(figure, pos);
+        if (matchingAxes == null) {
             return null;
         }
 
-        Integer[] datatips = (new ObjectSearcher()).search(axes, GraphicObjectProperties.__GO_DATATIP__, true);
-        if (datatips != null) {
-            int x = pos[0];
-            int y = pos[1];
+        for (Integer axes : matchingAxes) {
+            Integer[] datatips = (new ObjectSearcher()).search(axes, GraphicObjectProperties.__GO_DATATIP__, true);
+            if (datatips != null) {
+                int x = pos[0];
+                int y = pos[1];
 
-            for (int i = 0; i < datatips.length; ++i) {
-                Double[] tip_pos = (Double[])GraphicController.getController().getProperty(datatips[i], GraphicObjectProperties.__GO_DATATIP_DATA__);
-                double[] point = new double[] {tip_pos[0], tip_pos[1], tip_pos[2]};
-                double[] pix = CallRenderer.getPixelFrom3dCoordinates(axes, point);
+                for (int i = 0; i < datatips.length; ++i) {
+                    Double[] tip_pos = (Double[])GraphicController.getController().getProperty(datatips[i], GraphicObjectProperties.__GO_DATATIP_DATA__);
+                    double[] point = new double[] {tip_pos[0], tip_pos[1], tip_pos[2]};
+                    double[] pix = CallRenderer.getPixelFrom3dCoordinates(axes, point);
 
-                Integer size = CommonHandler.getMarkSize(datatips[i]);
-                Integer unit = CommonHandler.getMarkSizeUnit(datatips[i]);
+                    Integer size = CommonHandler.getMarkSize(datatips[i]);
+                    Integer unit = CommonHandler.getMarkSizeUnit(datatips[i]);
 
-                int finalSize = (unit == 1) ? (8 + 2 * size) : size;
-                finalSize /= 2;
+                    int finalSize = (unit == 1) ? (8 + 2 * size) : size;
+                    finalSize /= 2;
 
-                if ((Math.abs(x - pix[0]) <= finalSize) && (Math.abs(y - pix[1]) <= finalSize)) {
-                    return datatips[i];
+                    if ((Math.abs(x - pix[0]) <= finalSize) && (Math.abs(y - pix[1]) <= finalSize)) {
+                        return datatips[i];
+                    }
                 }
-            }
+            }            
         }
 
         return null;
