@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2009 - DIGITEO - Allan CORNET
  * Copyright (C) 2010 - Calixte DENIZET
  *
@@ -23,12 +23,6 @@
 */
 char **GetVariablesName(void);
 
-/**
-* Get all commands name in scilab
-* @return char array
-*/
-char **GetCommandsName(void);
-
 /**
 * get primitives name in scilab
 * @return char array
