@@ -85,6 +85,7 @@ static void usage(void)
     std::cerr << "      -l lang          : Change the language of scilab (default : en_US)." << std::endl;
     std::cerr << "      -nw              : Enable console mode." << std::endl;
     std::cerr << "      -nwni            : Enable terminal mode." << std::endl;
+    std::cerr << "      -nogui           : See -nwni." << std::endl;
     std::cerr << "      -ns              : Do not execute etc/scilab.start." << std::endl;
     std::cerr << "      -nouserstartup   : Do not execute user startup files (SCIHOME/scilab.ini|.scilab)." << std::endl;
     std::cerr << "      -noatomsautoload : Do not autoload eligible ATOMS modules." << std::endl;
@@ -260,6 +261,19 @@ static int get_option(const int argc, char *argv[], ScilabEngineInfo* _pSEI)
             printf("Argument \"-nwni\" is no longer supported.\nSee help page: https://help.scilab.org/scilab \n");
 #endif
             exit(-1);
+#endif
+        }
+        else if (!strcmp("-nogui", argv[i]))
+        {
+            _pSEI->iConsoleMode = 1;
+            _pSEI->iNoJvm = 1;
+#ifdef _MSC_VER
+#if WITH_CONSOLE_JAVA
+            MessageBoxA(NULL, "Argument \"-nogui\" is no longer supported.\nSee help page: https://help.scilab.org/scilab \n", "Error", MB_OK | MB_ICONERROR);
+#else
+            printf("Argument \"-nogui\" is no longer supported.\nSee help page: https://help.scilab.org/scilab \n");
+#endif
+            exit(-1);
 #endif
         }
         else if (!strcmp("-ns", argv[i]))
@@ -387,7 +401,7 @@ int WINAPI WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR szCmdLin
     {
         argv[i] = wide_string_to_UTF8(szArglist[i]);
     }
-
+    LocalFree(szArglist);
     setWindowShowMode(iCmdShow);
 
 #else
@@ -410,24 +424,7 @@ int main(int argc, char *argv[])
     setScilabMode(SCILAB_STD);
 #endif
 
-    //#if defined(_WIN32) && !defined(WITHOUT_GUI)
-    //    {
-    //        LPSTR my_argv[256];
-    //        int nArgs = 0;
-    //        LPWSTR *szArglist = CommandLineToArgvW(GetCommandLineW(), &nArgs);
-    //        if (szArglist)
-    //        {
-    //            for (int i = 0; i < nArgs; i++)
-    //            {
-    //                my_argv[i] = wide_string_to_UTF8(szArglist[i]);
-    //            }
-    //            LocalFree(szArglist);
-    //        }
-    //        get_option(nArgs, my_argv, pSEI);
-    //    }
-    //#else
     get_option(argc, argv, pSEI);
-    //#endif
 
     // if WITHOUT_GUI is defined
     // force Terminal IO -> Terminal IO + StartScilabEngine
@@ -519,24 +516,20 @@ int main(int argc, char *argv[])
     int val = setjmp(ScilabJmpEnv);
     if (!val)
     {
-        iRet = StartScilabEngine(pSEI);
-        if (iRet == 0)
+        val = StartScilabEngine(pSEI);
+        if (val == 0)
         {
-            iRet = RunScilabEngine(pSEI);
+            val = RunScilabEngine(pSEI);
         }
 
         StopScilabEngine(pSEI);
-        FREE(pSEI);
-        return iRet;
     }
     else
     {
         // We probably had a segfault so print error
         std::wcerr << getLastErrorMessage() << std::endl;
-        return val;
     }
 
-#if defined(_WIN32) && !defined(WITHOUT_GUI) && defined(WITH_CONSOLE_JAVA)
-    LocalFree(szArglist);
-#endif
+    FREE(pSEI);
+    return val;
 }
