@@ -1,5 +1,5 @@
 /*
- *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ *  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2014 - Scilab Enterprises - Cedric Delamarre
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -19,6 +19,6 @@
 #include <string.h>
 #include "dynlib_string.h"
 
-STRING_IMPEXP int os_wtoi(const wchar_t* pwcsStr);
+STRING_IMPEXP int os_wtoi(const wchar_t* pwcsStr, std::size_t* pos);
 
 #endif /* !__OS_WTOI_H__ */
