@@ -40,9 +40,9 @@ types::Function::ReturnValue sci_http_upload(types::typed_list &in, types::optio
         return types::Function::Error;
     }
 
-    if (_iRetCount > 2)
+    if (_iRetCount > 3)
     {
-        Scierror(78, _("%s: Wrong number of output argument(s): %d to %d expected.\n"), fname, 1, 2);
+        Scierror(78, _("%s: Wrong number of output argument(s): %d to %d expected.\n"), fname, 1, 3);
         return types::Function::Error;
     }
 
@@ -100,14 +100,6 @@ types::Function::ReturnValue sci_http_upload(types::typed_list &in, types::optio
         return types::Function::Error;
     }
 
-    char* pcVarName = wide_string_to_UTF8(in[2]->getAs<types::String>()->get(0));
-    for(auto f : files)
-    {
-        query.addFileToForm(pcVarName, f);
-    }
-    FREE(pcVarName);
-    cleanup(files);
-
     if(in.size() > 3)
     {
         // get data
@@ -136,6 +128,15 @@ types::Function::ReturnValue sci_http_upload(types::typed_list &in, types::optio
         }
     }
 
+    // Add file to form after data in case data contents is mandatory for file upload (identifier, ticket, ...)
+    char* pcVarName = wide_string_to_UTF8(in[2]->getAs<types::String>()->get(0));
+    for (auto f : files)
+    {
+        query.addFileToForm(pcVarName, f);
+    }
+    FREE(pcVarName);
+    cleanup(files);
+
     // specific optional argument
     for (const auto& o : opt)
     {
@@ -184,11 +185,16 @@ types::Function::ReturnValue sci_http_upload(types::typed_list &in, types::optio
     }
 
     out.push_back(query.getResult());
-    if(_iRetCount == 2)
+    if(_iRetCount > 1)
     {
         out.push_back(new types::Double((double)query.getResponseCode()));
     }
 
+    if(_iRetCount > 2)
+    {
+        out.push_back(query.getHeaders());
+    }
+
     return types::Function::OK;
 }
 
