@@ -571,7 +571,7 @@ std::string toJSON(scilabEnv env, scilabVar var, int indent)
 std::string toJSON(types::InternalType* it, int indent)
 {
     std::wostringstream os;
-    scilabVar var = (int*)it;
+    scilabVar var = (scilabVar)it;
 
     export_data(nullptr, var, indent, os);
 
@@ -639,7 +639,7 @@ struct JSONVar
             delete c;
         }
 
-        for (auto c : o1)
+        for (const auto& c : o1)
         {
             delete c.second;
         }
@@ -797,7 +797,7 @@ scilabVar createScilabVar(scilabEnv env, const JSONVar* v)
             size_t fsize = v->fields.size();
             std::vector<wchar_t*> fields;
             fields.reserve(fsize);
-            for (auto f : v->fields)
+            for (const auto& f : v->fields)
             {
                 fields.push_back(unescape(f.data()));
             }
@@ -820,51 +820,49 @@ scilabVar createScilabVar(scilabEnv env, const JSONVar* v)
                         scilab_setStructMatrix2dData(env, ret, fields[i], 0, 0, var);
                     }
                     break;
-
-                    case 1:
+                }
+                case 1:
+                {
+                    if (v->dims[0] == 1) //single struct [{"toto":42}]
                     {
-                        if (v->dims[0] == 1) //single struct [{"toto":42}]
+                        ret = scilab_createStruct(env);
+                        for (size_t i = 0; i < fsize; ++i)
                         {
-                            ret = scilab_createStruct(env);
-                            for (size_t i = 0; i < fsize; ++i)
-                            {
-                                scilab_addField(env, ret, fields[i]);
-                                scilabVar var = createScilabVar(env, v->o.at(v->fields[i])[0]);
-                                scilab_setStructMatrix2dData(env, ret, fields[i], 0, 0, var);
-                            }
+                            scilab_addField(env, ret, fields[i]);
+                            scilabVar var = createScilabVar(env, v->o.at(v->fields[i])[0]);
+                            scilab_setStructMatrix2dData(env, ret, fields[i], 0, 0, var);
                         }
-                        else //row vector [{"toto":1},{"toto":2}]
-                        {
-                            ret = scilab_createStructMatrix2d(env, 1, size);
-                            for (size_t i = 0; i < fsize; ++i)
-                            {
-                                scilab_addField(env, ret, fields[i]);
-                                for (int x = 0; x < size; ++x)
-                                {
-                                    scilabVar var = createScilabVar(env, v->o.at(v->fields[i])[x]);
-                                    scilab_setStructMatrix2dData(env, ret, fields[i], 0, x, var);
-                                }
-                            }
-                        }
-
-                        break;
                     }
-
-                    default: //2 and more
+                    else //row vector [{"toto":1},{"toto":2}]
                     {
-                        ret = scilab_createStructMatrix(env, (int)v->dims.size(), v->dims.data());
+                        ret = scilab_createStructMatrix2d(env, 1, size);
                         for (size_t i = 0; i < fsize; ++i)
                         {
                             scilab_addField(env, ret, fields[i]);
-                            std::vector<int> index(v->dims.size());
                             for (int x = 0; x < size; ++x)
                             {
-                                getIndexArray(x, v->dims, index);
                                 scilabVar var = createScilabVar(env, v->o.at(v->fields[i])[x]);
-                                scilab_setStructMatrixData(env, ret, fields[i], index.data(), var);
+                                scilab_setStructMatrix2dData(env, ret, fields[i], 0, x, var);
                             }
                         }
                     }
+
+                    break;
+                }
+                default: //2 and more
+                {
+                    ret = scilab_createStructMatrix(env, (int)v->dims.size(), v->dims.data());
+                    for (size_t i = 0; i < fsize; ++i)
+                    {
+                        scilab_addField(env, ret, fields[i]);
+                        std::vector<int> index(v->dims.size());
+                        for (int x = 0; x < size; ++x)
+                        {
+                            getIndexArray(x, v->dims, index);
+                            scilabVar var = createScilabVar(env, v->o.at(v->fields[i])[x]);
+                            scilab_setStructMatrixData(env, ret, fields[i], index.data(), var);
+                        }
+                    }
                 }
             }
 
@@ -1254,7 +1252,7 @@ JSONVar* import_data(const jsmntok_t* t)
                             }
 
                             //same fields
-                            for (auto c : v->a[i]->fields)
+                            for (const auto& c : v->a[i]->fields)
                             {
                                 if (std::find(fref.begin(), fref.end(), c) == fref.end())
                                 {
@@ -1273,7 +1271,7 @@ JSONVar* import_data(const jsmntok_t* t)
                         {
                             case 1: //row vector
                             {
-                                for (auto f : fref)
+                                for (const auto& f : fref)
                                 {
                                     for (auto d : v->a)
                                     {
@@ -1284,7 +1282,7 @@ JSONVar* import_data(const jsmntok_t* t)
                             }
                             case 2: //matrix
                             {
-                                for (auto f : fref)
+                                for (const auto& f : fref)
                                 {
                                     for (int j = 0; j < v->dims[1]; ++j)
                                     {
@@ -1306,7 +1304,7 @@ JSONVar* import_data(const jsmntok_t* t)
                             }
                             default: //hypermat
                             {
-                                for (auto f : fref)
+                                for (const auto& f : fref)
                                 {
                                     for (auto d : v->a)
                                     {
@@ -1329,6 +1327,11 @@ JSONVar* import_data(const jsmntok_t* t)
                         v->kind = JSON_STRUCT;
                         break;
                     }
+                    default:
+                    {
+                        //heterogeneous -> list
+                        v->kind = JSON_LIST;
+                    }
                 }
             }
             else
